=========================
The ``pyfastspm`` package
=========================

``pyfastspm`` is a python package to load, process, filter and analyze scanning probe microscopy movies acquired with the
FAST module.

.. toctree::
   :maxdepth: 1

   installation
   guide
   API_reference
   contributing
   authors

Accessing the repository
========================
The source code is hosted in a GitLab repository at this address::

   https://gitlab.com/fastspm/pyfastspm/

Feedback
========

Please report any feedback, bugs, or feature requests by opening an issue on the `issue tracker
<https://gitlab.com/fastspm/pyfastspm/issues>`_ of the code repository.
You should provide as much information as possible to reproduce the problem, and details of your desiderata.
